package javax.swing;

import java.awt.Container;
import java.awt.LayoutManager;
import java.awt.Component;
import java.awt.Graphics;
import java.awt.HeadlessException;
import sun.awt.SunToolkit;
import java.awt.BorderLayout;
import java.awt.Color;
import javax.accessibility.AccessibleContext;
import javax.accessibility.Accessible;
import java.applet.Applet;

public class JApplet extends Applet implements Accessible, RootPaneContainer, TransferHandler.HasGetTransferHandler
{
    protected JRootPane rootPane;
    protected boolean rootPaneCheckingEnabled;
    private TransferHandler transferHandler;
    protected AccessibleContext accessibleContext;
    
    public JApplet() throws HeadlessException {
        this.rootPaneCheckingEnabled = false;
        this.accessibleContext = null;
        TimerQueue sharedInstance = TimerQueue.sharedInstance();
        if (sharedInstance != null) {
            sharedInstance.startIfNeeded();
        }
        this.setForeground(Color.black);
        this.setBackground(Color.white);
        this.setLocale(JComponent.getDefaultLocale());
        this.setLayout(new BorderLayout());
        this.setRootPane(this.createRootPane());
        this.setRootPaneCheckingEnabled(true);
        this.setFocusTraversalPolicyProvider(true);
        SunToolkit.checkAndSetPolicy(this);
        this.enableEvents(8L);
    }
    
    protected JRootPane createRootPane() {
        JRootPane rootPane = new JRootPane();
        rootPane.setOpaque(true);
        return rootPane;
    }
    
    public void setTransferHandler(TransferHandler transferHandler) {
        TransferHandler transferHandler2 = this.transferHandler;
        SwingUtilities.installSwingDropTargetAsNecessary(this, this.transferHandler = transferHandler);
        this.firePropertyChange("transferHandler", transferHandler2, transferHandler);
    }
    
    @Override
    public TransferHandler getTransferHandler() {
        return this.transferHandler;
    }
    
    @Override
    public void update(Graphics g) {
        this.paint(g);
    }
    
    public void setJMenuBar(JMenuBar menuBar) {
        this.getRootPane().setMenuBar(menuBar);
    }
    
    public JMenuBar getJMenuBar() {
        return this.getRootPane().getMenuBar();
    }
    
    protected boolean isRootPaneCheckingEnabled() {
        return this.rootPaneCheckingEnabled;
    }
    
    protected void setRootPaneCheckingEnabled(boolean rootPaneCheckingEnabled) {
        this.rootPaneCheckingEnabled = rootPaneCheckingEnabled;
    }
    
    @Override
    protected void addImpl(Component component, Object o, int n) {
        if (this.isRootPaneCheckingEnabled()) {
            this.getContentPane().add(component, o, n);
        }
        else {
            super.addImpl(component, o, n);
        }
    }
    
    @Override
    public void remove(Component component) {
        if (component == this.rootPane) {
            super.remove(component);
        }
        else {
            this.getContentPane().remove(component);
        }
    }
    
    @Override
    public void setLayout(LayoutManager layoutManager) {
        if (this.isRootPaneCheckingEnabled()) {
            this.getContentPane().setLayout(layoutManager);
        }
        else {
            super.setLayout(layoutManager);
        }
    }
    
    @Override
    public JRootPane getRootPane() {
        return this.rootPane;
    }
    
    protected void setRootPane(JRootPane rootPane) {
        if (this.rootPane != null) {
            this.remove(this.rootPane);
        }
        this.rootPane = rootPane;
        if (this.rootPane != null) {
            int rootPaneCheckingEnabled = this.isRootPaneCheckingEnabled();
            try {
                this.setRootPaneCheckingEnabled(false);
                this.add(this.rootPane, "Center");
            }
            finally {
                this.setRootPaneCheckingEnabled((boolean)rootPaneCheckingEnabled);
            }
        }
    }
    
    @Override
    public Container getContentPane() {
        return this.getRootPane().getContentPane();
    }
    
    @Override
    public void setContentPane(Container contentPane) {
        this.getRootPane().setContentPane(contentPane);
    }
    
    @Override
    public JLayeredPane getLayeredPane() {
        return this.getRootPane().getLayeredPane();
    }
    
    @Override
    public void setLayeredPane(JLayeredPane layeredPane) {
        this.getRootPane().setLayeredPane(layeredPane);
    }
    
    @Override
    public Component getGlassPane() {
        return this.getRootPane().getGlassPane();
    }
    
    @Override
    public void setGlassPane(Component glassPane) {
        this.getRootPane().setGlassPane(glassPane);
    }
    
    @Override
    public Graphics getGraphics() {
        JComponent.getGraphicsInvoked(this);
        return super.getGraphics();
    }
    
    @Override
    public void repaint(long tm, int x, int y, int width, int height) {
        if (RepaintManager.HANDLE_TOP_LEVEL_PAINT) {
            RepaintManager.currentManager(this).addDirtyRegion(this, x, y, width, height);
        }
        else {
            super.repaint(tm, x, y, width, height);
        }
    }
    
    @Override
    protected String paramString() {
        return super.paramString() + ",rootPane=" + ((this.rootPane != null) ? this.rootPane.toString() : "") + ",rootPaneCheckingEnabled=" + (this.rootPaneCheckingEnabled ? "true" : "false");
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new JApplet.AccessibleJApplet();
        }
        return this.accessibleContext;
    }
    
    protected class AccessibleJApplet extends Applet.AccessibleApplet
    {
    }
}
